==> nextcloud-app-calendar-1.5.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/pt_BR.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendário",
    "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Informamos que %s publicou o calendário »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "Saudações!",
    "Recipient" : "Destinatário",
    "Too many redirects. Aborting ..." : "Muitos redirecionamentos. Abortando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "O servidor remoto não nos deu acesso ao calendário (erro HTTP {%s})",
    "Error connecting to remote server" : "Erro ao conectar o servidor remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Erro ao solicitar recurso no servidor remoto. Isso poderia estar relacionado a uma incompatibilidade de certificado",
    "Error requesting resource on remote server" : "Erro ao solicitar recurso no servidor remoto",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Espaço",
    "Unknown" : "Desconhecido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "Não atende",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Você está em um fuso horário desconhecido ({tz}), retornando para UTC",
    "Please create a calendar first." : "Por favor crie um calendário primeiro.",
    "New event" : "Novo evento",
    "CalDAV address for clients" : "Endereço CalDAV para clientes",
    "Error saving WebCal-calendar" : "Erro salvando o calendário WebCal",
    "WebDAV address for subscriptions" : "Endereço WebDAV para inscrições",
    "Email has been sent." : "O e-mail foi enviado.",
    "There was an issue while sending your email." : "Houve um problema ao enviar o e-mail.",
    "group" : "grupo",
    "Details" : "Detalhes",
    "Attendees" : "Participantes",
    "Reminders" : "Lembretes",
    "Repeating" : "Repetindo",
    "When shared show full event" : "Quando compartilhado mostrar evento completo",
    "When shared show only busy" : "Quando compartilhado mostrar apenas ocupado",
    "When shared hide this event" : "Quando compartilhado esconder este evento",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativa",
    "Cancelled" : "Cancelado",
    "Please add a title." : "Por favor, adicione um título.",
    "Please select a calendar." : "Por favor, selecione um calendário.",
    "The event can not end before it starts." : "O evento não pode terminar antes de começar.",
    "Global" : "Global",
    "None" : "Nenhum",
    "Every day" : "Todos os dias",
    "Every week" : "Todas as semanas",
    "Every month" : "Todo mês",
    "Every year" : "Todo ano",
    "never" : "nunca",
    "after" : "após",
    "How about getting started by importing some calendars?" : "Que tal começar importando alguns calendários?",
    "At time of event" : "No momento do evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizadas",
    "Audio" : "Áudio",
    "Email" : "E-mail",
    "Pop-up" : "Pop-up",
    "sec" : "seg",
    "min" : "min",
    "hours" : "horas",
    "days" : "dias",
    "week" : "semana",
    "before" : "antes",
    "start" : "início",
    "end" : "fim",
    "Editing reminders of unknown type not supported." : "Edição de lembretes de tipos desconhecidos não são suportados.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported {imported} objects" : "Objetos importados {imported} com sucesso",
    "Imported {imported} out of {all}, skipped one duplicate" : "Importados {imported} de {all}, uma duplicata ignorada",
    "Imported {imported} out of {all}, one failure" : "Importados {imported} de {all}, uma falha",
    "Imported {imported} out of {all}, {errors} failures" : "Importados {imported} de {all}, {errors} falhas",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Importados {imported} de {all}, {duplicates} duplicatas ignoradas",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Importados {imported} de {all}, {errors} falhas, {duplicates} duplicatas ignoradas",
    "Audio alarm {time} before the event starts" : "Alarme de áudio {time} antes do evento começar",
    "Pop-up {time} before the event starts" : "Janela popup {time} antes do evento começar",
    "Email {time} before the event starts" : "Email {time} antes do evento começar",
    "None {time} before the event starts" : "Nada {time} antes do evento começar",
    "{type} {time} before the event starts" : "{type} {time} antes do evento iniciar",
    "Audio alarm {time} before the event ends" : "Alarme de áudio {time} antes do evento terminar",
    "Pop-up {time} before the event ends" : "Janela popup {time} antes do evento terminar",
    "Email {time} before the event ends" : "Email  {time} antes do evento terminar",
    "None {time} before the event ends" : "Nada {time} antes do evento terminar",
    "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
    "Audio alarm {time} after the event starts" : "Alarme de áudio {time} após o evento começar",
    "Pop-up {time} after the event starts" : "Janela popup {time} após o evento começar",
    "Email {time} after the event starts" : "Email {time} após o evento começar",
    "None {time} after the event starts" : "Nada {time} após o evento começar",
    "{type} {time} after the event starts" : "{type} {time} após o evento iniciar",
    "Audio alarm {time} after the event ends" : "Alarme de áudio {time} após o evento terminar",
    "Pop-up {time} after the event ends" : "Janela popup {time} após o evento terminar",
    "Email {time} after the event ends" : "Email {time} após o evento terminar",
    "None {time} after the event ends" : "Nada {time} após o evento terminar",
    "{type} {time} after the event ends" : "{type} {time} após o evento terminar",
    "Audio alarm at the event's start" : "Alarme de áudio no início do evento",
    "Pop-up at the event's start" : "Janela popup no início do evento",
    "Email at the event's start" : "Email no início do evento",
    "None at the event's start" : "Nada no início do evento",
    "{type} at the event's start" : "{type} no início do evento",
    "Audio alarm at the event's end" : "Alarme de áudio no fim do evento",
    "Pop-up at the event's end" : "Janela popup no fim do evento",
    "Email at the event's end" : "Email no fim do evento",
    "None at the event's end" : "Nada no fim do evento",
    "{type} at the event's end" : "{type} no final do evento",
    "Audio alarm at {time}" : "Alarme de áudio em {time}",
    "Pop-up at {time}" : "Janela popup em {time}",
    "Email at {time}" : "Email em {time}",
    "None at {time}" : "Nada em {time}",
    "{type} at {time}" : "{type} em {time}",
    "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
    "Please enter a valid WebCal-URL" : "Por favor entre uma URL válida para WEbCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Erro severo no proxy WebCal. Por favor contacte o administrador para mais informações.",
    "Title of the Event" : "Título do evento",
    "Starts" : "Inicia em",
    "Ends" : "Termina em",
    "All day Event" : "Evento todo o dia",
    "Delete" : "Excluir",
    "Cancel" : "Cancelar",
    "More ..." : "Mais...",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Close" : "Fechar",
    "Location" : "Localização",
    "Description" : "Descrição",
    "Event status" : "Status do evento",
    "Visibility when sharing" : "Visível quando compartilhando",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s publicou o calendário%s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Gostaríamos de avisá-lo que %s publicou o calendário {boldstart}%s{boldend}",
    "Click here to access it" : "Clique aqui para acessar",
    "We wanted to inform you that %s has published the calendar %s." : "Gostaríamos de avisá-lo que %s publicou o calendário %s.",
    "Click on the link below to access it" : "Clique no link abaixo para acessá-lo",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Today" : "Hoje",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns eventos neste calendário estão corrompidos. Por favor, verifique o console JS para mais informações.",
    "Share Calendar" : "Compartilhar Calendário",
    "Shared" : "Compartilhado",
    "More" : "Mais",
    "Edit" : "Editar",
    "Link" : "Link",
    "iCal link" : "Link do iCal",
    "Download" : "Baixar",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "can edit" : "pode editar",
    "Share link" : "Compartilhar link",
    "Public access" : "Acesso público",
    "Email link to person" : "Enviar link via e-mail para alguém",
    "Send" : "Enviar",
    "New Calendar" : "Novo Calendário",
    "Name" : "Nome",
    "New Subscription" : "Nova Subscrição",
    "Go back" : "Voltar",
    "Go forward" : "Avançar",
    "Calendar does not exist" : "O calendário não existe",
    "Maybe you got a wrong link or the calendar was unshared?" : "Será o link errado ou calendário descompartilhado?",
    "Edit event" : "Editar evento",
    "Delete Event" : "Excluir Evento",
    "Save Event" : "Salvar Evento",
    "Time" : "Horário",
    "Type" : "Digite",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "vezes a cada",
    "Email reminders have not been implemented in the CalDAV server yet, hence no email reminders will be send." : "Lembretes via email ainda não foram implementados no servidor CalDAV então nenhum destes lembretes será enviado.",
    "Add" : "Adicionar",
    "Email address of attendee" : "Endereço de e-mail do atendente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de e-mail nas configurações pessoais, a fim de adicionar participantes.",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Esta regra de repetição de evento ainda não é suportada.",
    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas serão adicionados em futuras atualizações.",
    "Reset repeating rule" : "Resetar a regra de repetição",
    "Repeat every ..." : "Repetir a cada...",
    "end repeat ..." : "fim da repetição...",
    "times" : "vezes",
    "Import Calendars" : "Importar Calendários",
    "Import canceled" : "Importação cancelada",
    "Analyzing calendar" : "Analisando calendário",
    "The file contains objects incompatible with the selected calendar" : "O arquivo contém objetos incompatíveis com o calendário selecionado",
    "New calendar" : "Novo calendário",
    "File is empty" : "Arquivo vazio",
    "Import scheduled" : "Importar agendados",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartilhou o calendário <strong>%s</strong> com você",
    "Embed" : "Incorporar",
    "Iframe to integrate" : "Iframe a integrar",
    "Publish URL" : "Publicar URL",
    "Settings & import" : "Configurações & Importação",
    "Skip simple event editor" : "Saltar editor de eventos simples",
    "Show week numbers" : "Mostrar o número das semanas",
    "Import calendar" : "Importar calendário",
    "No Calendars selected for import" : "Nenhum Calendário foi selecionado para importação",
    "Primary CalDAV address" : "Endereço CalDAV primário",
    "iOS/OS X CalDAV address" : "Endereço iOS/OS X CalDAV ",
    "Subscribe" : "Inscrever-se"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-calendar-1.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/pt_BR.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendário",
    "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Informamos que %s publicou o calendário »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "Saudações!",
    "Recipient" : "Destinatário",
    "Too many redirects. Aborting ..." : "Muitos redirecionamentos. Abortando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "O servidor remoto não nos deu acesso ao calendário (erro HTTP {%s})",
    "Error connecting to remote server" : "Erro ao conectar o servidor remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Erro ao solicitar recurso no servidor remoto. Isso poderia estar relacionado a uma incompatibilidade de certificado",
    "Error requesting resource on remote server" : "Erro ao solicitar recurso no servidor remoto",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Espaço",
    "Unknown" : "Desconhecido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "Não atende",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Você está em um fuso horário desconhecido ({tz}), retornando para UTC",
    "Please create a calendar first." : "Por favor crie um calendário primeiro.",
    "New event" : "Novo evento",
    "CalDAV address for clients" : "Endereço CalDAV para clientes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns eventos neste calendário estão corrompidos. Por favor, verifique o console JS para mais informações.",
    "Share Calendar" : "Compartilhar Calendário",
    "Shared" : "Compartilhado",
    "Could not save WebCal-calendar" : "Não foi possível salvar WebCal-calendar",
    "WebDAV address for subscriptions" : "Endereço WebDAV para inscrições",
    "Email sent." : "E-mail enviado.",
    "Could not send your email." : "Não foi possível enviar seu email.",
    "group" : "grupo",
    "Details" : "Detalhes",
    "Attendees" : "Participantes",
    "Reminders" : "Lembretes",
    "Repeating" : "Repetindo",
    "When shared show full event" : "Quando compartilhado mostrar evento completo",
    "When shared show only busy" : "Quando compartilhado mostrar apenas ocupado",
    "When shared hide this event" : "Quando compartilhado esconder este evento",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativa",
    "Cancelled" : "Cancelado",
    "Please add a title." : "Por favor, adicione um título.",
    "Please select a calendar." : "Por favor, selecione um calendário.",
    "The event can not end before it starts." : "O evento não pode terminar antes de começar.",
    "Global" : "Global",
    "None" : "Nenhum",
    "Every day" : "Todos os dias",
    "Every week" : "Todas as semanas",
    "Every month" : "Todo mês",
    "Every year" : "Todo ano",
    "never" : "nunca",
    "after" : "após",
    "How about getting started by importing some calendars?" : "Que tal começar importando alguns calendários?",
    "At time of event" : "No momento do evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizadas",
    "Audio" : "Áudio",
    "Email" : "E-mail",
    "Pop-up" : "Pop-up",
    "sec" : "seg",
    "min" : "min",
    "hours" : "horas",
    "days" : "dias",
    "week" : "semana",
    "before" : "antes",
    "start" : "início",
    "end" : "fim",
    "Editing reminders of unknown type not supported." : "Edição de lembretes de tipos desconhecidos não são suportados.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported {imported} objects" : "Objetos importados {imported} com sucesso",
    "Imported {imported} out of {all}, skipped one duplicate" : "Importados {imported} de {all}, uma duplicata ignorada",
    "Imported {imported} out of {all}, one failure" : "Importados {imported} de {all}, uma falha",
    "Imported {imported} out of {all}, {errors} failures" : "Importados {imported} de {all}, {errors} falhas",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Importados {imported} de {all}, {duplicates} duplicatas ignoradas",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Importados {imported} de {all}, {errors} falhas, {duplicates} duplicatas ignoradas",
    "Audio alarm {time} before the event starts" : "Alarme de áudio {time} antes do evento começar",
    "Pop-up {time} before the event starts" : "Janela popup {time} antes do evento começar",
    "Email {time} before the event starts" : "Email {time} antes do evento começar",
    "None {time} before the event starts" : "Nada {time} antes do evento começar",
    "{type} {time} before the event starts" : "{type} {time} antes do evento iniciar",
    "Audio alarm {time} before the event ends" : "Alarme de áudio {time} antes do evento terminar",
    "Pop-up {time} before the event ends" : "Janela popup {time} antes do evento terminar",
    "Email {time} before the event ends" : "Email  {time} antes do evento terminar",
    "None {time} before the event ends" : "Nada {time} antes do evento terminar",
    "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
    "Audio alarm {time} after the event starts" : "Alarme de áudio {time} após o evento começar",
    "Pop-up {time} after the event starts" : "Janela popup {time} após o evento começar",
    "Email {time} after the event starts" : "Email {time} após o evento começar",
    "None {time} after the event starts" : "Nada {time} após o evento começar",
    "{type} {time} after the event starts" : "{type} {time} após o evento iniciar",
    "Audio alarm {time} after the event ends" : "Alarme de áudio {time} após o evento terminar",
    "Pop-up {time} after the event ends" : "Janela popup {time} após o evento terminar",
    "Email {time} after the event ends" : "Email {time} após o evento terminar",
    "None {time} after the event ends" : "Nada {time} após o evento terminar",
    "{type} {time} after the event ends" : "{type} {time} após o evento terminar",
    "Audio alarm at the event's start" : "Alarme de áudio no início do evento",
    "Pop-up at the event's start" : "Janela popup no início do evento",
    "Email at the event's start" : "Email no início do evento",
    "None at the event's start" : "Nada no início do evento",
    "{type} at the event's start" : "{type} no início do evento",
    "Audio alarm at the event's end" : "Alarme de áudio no fim do evento",
    "Pop-up at the event's end" : "Janela popup no fim do evento",
    "Email at the event's end" : "Email no fim do evento",
    "None at the event's end" : "Nada no fim do evento",
    "{type} at the event's end" : "{type} no final do evento",
    "Audio alarm at {time}" : "Alarme de áudio em {time}",
    "Pop-up at {time}" : "Janela popup em {time}",
    "Email at {time}" : "Email em {time}",
    "None at {time}" : "Nada em {time}",
    "{type} at {time}" : "{type} em {time}",
    "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
    "Please enter a valid WebCal-URL" : "Por favor entre uma URL válida para WEbCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Erro severo no proxy WebCal. Por favor contacte o administrador para mais informações.",
    "Title of the Event" : "Título do evento",
    "Starts" : "Inicia em",
    "Ends" : "Termina em",
    "All day Event" : "Evento todo o dia",
    "Delete" : "Excluir",
    "Cancel" : "Cancelar",
    "More ..." : "Mais...",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Close" : "Fechar",
    "Location" : "Localização",
    "Description" : "Descrição",
    "Event status" : "Status do evento",
    "Visibility when sharing" : "Visível quando compartilhando",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s publicou o calendário%s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Gostaríamos de avisá-lo que %s publicou o calendário {boldstart}%s{boldend}",
    "Click here to access it" : "Clique aqui para acessar",
    "We wanted to inform you that %s has published the calendar %s." : "Gostaríamos de avisá-lo que %s publicou o calendário %s.",
    "Click on the link below to access it" : "Clique no link abaixo para acessá-lo",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Today" : "Hoje",
    "More" : "Mais",
    "Edit" : "Editar",
    "Link" : "Link",
    "iCal link" : "Link do iCal",
    "Download" : "Baixar",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "can edit" : "pode editar",
    "Share link" : "Compartilhar link",
    "Public access" : "Acesso público",
    "Email link to person" : "Enviar link via e-mail para alguém",
    "Send" : "Enviar",
    "New Calendar" : "Novo Calendário",
    "Name" : "Nome",
    "New Subscription" : "Nova Subscrição",
    "Go back" : "Voltar",
    "Go forward" : "Avançar",
    "Calendar does not exist" : "O calendário não existe",
    "Maybe you got a wrong link or the calendar was unshared?" : "Será o link errado ou calendário descompartilhado?",
    "Edit event" : "Editar evento",
    "Delete Event" : "Excluir Evento",
    "Save Event" : "Salvar Evento",
    "Time" : "Horário",
    "Type" : "Digite",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "vezes a cada",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Os lembretes de e-mail ainda não foram implementados no servidor CalDAV, portanto nenhum será enviado.",
    "Add" : "Adicionar",
    "Email address of attendee" : "Endereço de e-mail do atendente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de e-mail nas configurações pessoais, a fim de adicionar participantes.",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Esta regra de repetição de evento ainda não é suportada.",
    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas serão adicionados em futuras atualizações.",
    "Reset repeating rule" : "Resetar a regra de repetição",
    "Repeat every ..." : "Repetir a cada...",
    "end repeat ..." : "fim da repetição...",
    "times" : "vezes",
    "Import Calendars" : "Importar Calendários",
    "Import canceled" : "Importação cancelada",
    "Analyzing calendar" : "Analisando calendário",
    "The file contains objects incompatible with the selected calendar" : "O arquivo contém objetos incompatíveis com o calendário selecionado",
    "New calendar" : "Novo calendário",
    "File is empty" : "Arquivo vazio",
    "Import scheduled" : "Importar agendados",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartilhou o calendário <strong>%s</strong> com você",
    "Embed" : "Incorporar",
    "Iframe to integrate" : "Iframe a integrar",
    "Publish URL" : "Publicar URL",
    "Settings & import" : "Configurações & Importação",
    "Skip simple event editor" : "Saltar editor de eventos simples",
    "Show week numbers" : "Mostrar o número das semanas",
    "Import calendar" : "Importar calendário",
    "No Calendars selected for import" : "Nenhum Calendário foi selecionado para importação",
    "Primary CalDAV address" : "Endereço CalDAV primário",
    "iOS/OS X CalDAV address" : "Endereço iOS/OS X CalDAV ",
    "Subscribe" : "Inscrever-se"
},
"nplurals=2; plural=(n > 1);");
